package com.zfire.jiasm.syncdata.upload;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.IdWorker;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.gree.GreeLogic;
import com.zfire.jiasm.syncdata.helper.GreeFileResponseHelper;
import com.zfire.jiasm.syncdata.helper.GreeFileSaveHelper;
import com.zfire.jiasm.syncdata.http.PostObjectSample;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.BrandService;
import com.zfire.jiasm.syncdata.plus.service.OutWorkerCertificateUploadService;
import com.zfire.jiasm.syncdata.plus.service.WorkerBrandAccountService;
import com.zfire.jiasm.syncdata.plus.service.WorkerService;
import com.zfire.jiasm.syncdata.response.ResultData;
import com.zfire.jiasm.syncdata.utils.oss.OSSUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.jetbrains.annotations.Nullable;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.io.BufferedInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.net.HttpURLConnection;
import java.net.URL;
import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 同步文件到格力总部
 */
@Slf4j
@Component
public class UploadFileTOGreeBefTask {
    @Resource
    WorkerService workerService;
    @Resource
    OSSUtil ossUtil;
    @Resource
    GreeLogic greeLogic;
    @Resource
    OutWorkerCertificateUploadService outWorkerCertificateUploadService;
    @Resource
    WorkerBrandAccountService workerBrandAccountService;
    @Resource
    BaseService baseService;

    // 师傅信息附件同步到格力总数
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    public void processUploadTask() throws Exception {
        if (1==1){
            return;
        }

        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<OutWorkerCertificateUpload> recs = new ArrayList<>();
        List<WorkerBrandAccount> workerWdnos = new ArrayList<>();
        String fileo ="";
        String filet ="";
        String fid1 = "";
        String fid2 = "";
        Integer count = 0;

        // 提取品牌信息 用于多品牌数据同步目前仅格力，可以先不用做
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        log.info("开始同步师傅证件信息: {}",sdf.format(new Date()));

        // 获取待同步到格力总部师傅的证件信息
        recs = getWorkerUploads();

        for (OutWorkerCertificateUpload item:recs){
            fileo ="";
            filet ="";
            fid1 = "";
            fid2 = "";
            count = 0;

           //  查看师傅是否已选中品牌商
            workerWdnos = workerBrandAccountService.lambdaQuery()
                    .eq(WorkerBrandAccount::getWorkerId, item.getWorkerId())
                    .eq(WorkerBrandAccount::getBrandWorkerStatus,"ON")
                    .eq(WorkerBrandAccount::getBrandId, brand.getBrandId()).list();

            // 未选择品牌商
            if (workerWdnos.size()<1){
                updateWorkCertificateerror(item.getId(),"师傅未选择品牌商信息");
                continue;
            }

            //  判断师傅入驻的商户网点
            count = getCount(workerWdnos, count);
            if (count.equals(workerWdnos.size())){
                updateWorkCertificateerror(item.getId(),"师傅未入驻品牌商网点");
                continue;
            }

            // 生成图片
            if (StringUtils.isNotEmpty(item.getFileUrl()) && (StringUtils.isEmpty(item.getFileUrlOut()))){
                fid1 = IdWorker.getIdStr();
                saveToFile(ossUtil.getUrlWw(item.getFileUrl()),fid1);
                // 获取文件
                fileo =fid1 + ".jpeg";
            }
            if (StringUtils.isNotEmpty(item.getFileUrl2()) && (StringUtils.isEmpty(item.getFileUrl2Out()))){
                fid2 = IdWorker.getIdStr();
                saveToFile(ossUtil.getUrlWw(item.getFileUrl()),fid2);
                // 获取文件
                filet =fid2 + ".jpeg";
            }

            // 上传图片 按网点上传
            for (WorkerBrandAccount wdno: workerWdnos){
                uploadFileexc(fileo, filet, fid1, fid2,wdno.getBrandWebsitNumber(),item);
            }
        }
        log.info("同步师傅证件信息结束: {}",sdf.format(new Date()));
    }

    private Boolean uploadFileexc(String fileo, String filet, String fid1, String fid2,String wdno,OutWorkerCertificateUpload item) throws Exception {
        Boolean uploadfile = Boolean.TRUE;
        Boolean onlyone = Boolean.FALSE;

        if (StringUtils.isEmpty(wdno)){
            return Boolean.TRUE;
        }

        // 先上传第一个图片
        if (StringUtils.isNotEmpty(fileo)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fid1+".jpeg");
                // 2:文件上传
                fileo = System.getProperty("java.io.tmpdir") + fid1 + ".jpeg";
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(fileo, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对像
                    getSaveFileInfo(fid1, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        if (StringUtils.isEmpty(filet)){
                            // 说明只有第一个图片
                            onlyone = Boolean.TRUE;
                        }
                        updateWorkCertificatesave(item,responses.getData().getId(),1,uploadfile,onlyone);
                    } else {
                        // 失败
                        uploadfile = Boolean.FALSE;
                        updateWorkCertificateerror(item.getId(),"保存证件正面文件到格力总部失败");
                    }
                } else {
                    updateWorkCertificateerror(item.getId(),"上传图片到OSS失败");
                  }
            } else {
                updateWorkCertificateerror(item.getId(),"获取签名信息失败");
                return Boolean.TRUE;
            }
        }

        if (StringUtils.isNotEmpty(filet)){
            // 1: 获取签名信息
            GreeFileResponseHelper response =  greeLogic.ossGetSignt(wdno,"GET");
            if (response.getStatusCode() == 200){
                ResultData resultData = JSONObject.parseObject(response.getData().toString(), ResultData.class);
                resultData.getExtData().setDir(resultData.getExtData().getDir()+"/"+fid2+".jpeg");
                // 2:文件上传
                filet = System.getProperty("java.io.tmpdir") + fid2 + ".jpeg";
                PostObjectSample ossPostObject = new PostObjectSample();
                String result = ossPostObject.PostObject(filet, resultData.getExtData());
                // 3: 保存文件
                if (StringUtils.isEmpty(result.trim())){
                    Map<String,String>req = new HashMap<>();
                    // 生成对像
                    getSaveFileInfo(fid2, resultData, req);
                    GreeFileSaveHelper responses = greeLogic.greePostSaveFile(req);

                    if (responses.getStatusCode() == 200){
                        // 保存文件ID   responses.getData().getId()
                        updateWorkCertificatesave(item,responses.getData().getId(),2,uploadfile,onlyone);
                    } else {
                        // 失败
                        updateWorkCertificateerror(item.getId(),"保存证件反面文件到格力总部失败");
                        return Boolean.TRUE;
                    }
                } else {
                    updateWorkCertificateerror(item.getId(),"上传图片到OSS失败");
                    return Boolean.TRUE;
                }
            } else {
                updateWorkCertificateerror(item.getId(),"获取签名信息失败");
                return Boolean.TRUE;
            }
        }
        return Boolean.FALSE;
    }








    private Integer getCount(List<WorkerBrandAccount> workerWdnos, Integer count) {
        for (WorkerBrandAccount w: workerWdnos){
            if (StringUtils.isEmpty(w.getBrandWebsitNumber())){
                count++;
            }
        }
        return count;
    }

    private void updateWorkCertificateerror(Long id, String msg) {
        OutWorkerCertificateUpload v = new OutWorkerCertificateUpload();
        v.setId(id);
        v.setSyncTime(new Date());
        v.setSyncErrorMsg(msg);
        outWorkerCertificateUploadService.updateById(v);
    }

    private void updateWorkCertificatesave(OutWorkerCertificateUpload i, String file, Integer flag,
                                           Boolean bool, Boolean onlyOne) {
        OutWorkerCertificateUpload v = new OutWorkerCertificateUpload();
        v.setId(i.getId());
        if (flag ==1){
            v.setFileUrlOut(file);
            if (onlyOne){
                v.setSyncStatus(1);
            }
        } else {
            v.setFileUrl2Out(file);
            if (bool){
                v.setSyncStatus(1);
            }
        }
        v.setSyncTime(new Date());
        outWorkerCertificateUploadService.updateById(v);
    }

    private void getSaveFileInfo(String id1, ResultData resultData, Map<String, String> req) {
        req.put("bizAppId","flydiy-auto-sit-default-front-greeshmerge");
        req.put("bizTable","default");
        req.put("bizType","default");
        req.put("accessType","auth");
        req.put("url", resultData.getExtData().getDir());
        req.put("name", id1 +".jpeg");
    }

    private void saveToFile(String desUrl,String id){
        FileOutputStream fos = null;
        BufferedInputStream bis = null ;
        HttpURLConnection httpUrl =null;
        URL url =null;
        int BUFFER_SIZE = 1024;
        byte[] buf = new byte[BUFFER_SIZE];
        int size = -1;

        try {
            url = new URL(desUrl);
            httpUrl = (HttpURLConnection) url.openConnection();
            httpUrl.connect();
            bis = new BufferedInputStream(httpUrl.getInputStream());
            fos = new FileOutputStream(System.getProperty("java.io.tmpdir") + id + ".jpeg");
            while (true){
                size = bis.read(buf);
                if (size == -1){
                    break;
                }
                fos.write(buf,0,size);
            }
            fos.flush();
        } catch (IOException e){
        } catch (ClassCastException e){
        } finally {
            try{
                fos.close();
                bis.close();
                httpUrl.disconnect();
            }catch (IOException e){
            }catch (NullPointerException e){
            }
        }
    }

    @Nullable
    private Worker getWorker(WorkerUpload item) {
        Worker worker = workerService.lambdaQuery()
                .eq(Worker::getWorkerId, item.getWorkerId())
                .eq(Worker::getIsApplyOver,"YES").one();
        if (worker ==null){
            return null;
        }
        return worker;
    }


    /**
     * 该表只进行增加数所
     *     相同类型数据只取最大ID
     * @return
     */
    private List<OutWorkerCertificateUpload> getWorkerUploads() {
        // 同步标志-synStatus(0:待同步;1:已同步;99:同步失败)
        return outWorkerCertificateUploadService.lambdaQuery()
                .eq(OutWorkerCertificateUpload::getSyncStatus,0)
                .list();
    }


}
