package com.zfire.jiasm.syncdata.upload;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.zfire.jiasm.syncdata.base.BaseService;
import com.zfire.jiasm.syncdata.base.WorkerCertificateInfo;
import com.zfire.jiasm.syncdata.constant.DictTypeEnum;
import com.zfire.jiasm.syncdata.gree.GreeLogic;
import com.zfire.jiasm.syncdata.helper.GreeResponseHelper;
import com.zfire.jiasm.syncdata.plus.entity.*;
import com.zfire.jiasm.syncdata.plus.service.*;
import com.zfire.jiasm.syncdata.request.SignSplb;
import com.zfire.jiasm.syncdata.request.WorkUploadInfo;
import com.zfire.jiasm.syncdata.request.ZJInfo;
import com.zfire.jiasm.syncdata.response.WorkerUploadResponse;
import lombok.extern.slf4j.Slf4j;
import org.jetbrains.annotations.Nullable;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 同步师傅信息到格力总部
 */
@Slf4j
@Component
public class UploadWorkerTOGreeTask {
    @Resource
    BaseService baseService;
    @Resource
    WorkerUploadService workerUploadService;
    @Resource
    WorkerService workerService;
    @Resource
    WorkerBrandAccountService workerBrandAccountService;
    @Resource
    WorkerStreetService workerStreetService;
    @Resource
    WorkerCertService workerCertService;
    @Resource
    WorkerServiceCategoryDetailService workerServiceCategoryDetailService;
    @Resource
    SysDictRefService sysDictRefService;
    @Resource
    SysDictService sysDictService;
    @Resource
    GreeLogic greeLogic;
    @Resource
    OutWorkerCertificateUploadService outWorkerCertificateUploadService;


    private ObjectMapper mapper;


    /** 同步师傅信息到格力总部
     * 所有证件都必须重新上传一次
     * 师傅所在网点都要上传一次
     * @throws Exception
     */
    @Scheduled(fixedDelay = 1 * 60 * 1000)
    public void uploadWorkProcess() throws Exception {
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        List<WorkerUpload> recs = new ArrayList<>();
        Worker worker = new Worker();
        WorkerBrandAccount workerBrandAccount = new WorkerBrandAccount();
        WorkerStreet workerStreet = new WorkerStreet();
        Boolean flag = Boolean.FALSE;

        String apiPathWork = "/outapp/wxg/add";

        // 提取品牌信息
        Brand brand = baseService.getBrand();
        if (brand == null) {
            return;
        }

        log.info("开始同步师傅信息到格力总部: {}",sdf.format(new Date()));

        // 获取待同步数据
        recs = getWorkerUploads();

        for (WorkerUpload item:recs){
            flag = Boolean.FALSE;
            WorkUploadInfo req = new WorkUploadInfo();
            WorkerCertificateInfo workerCertificateInfo = new WorkerCertificateInfo();

            // 获取师傅信息
            worker = getWorker(item);
            if (worker == null){
                continue;
            }

            //  查看师傅是否已选中品牌商
            workerBrandAccount = getWorkerBrandAccount(brand, item, worker);
            if (workerBrandAccount == null) {
                continue;
            }

            // 查看师傅服务区域
            workerStreet = getWorkerStreet(item, worker);
            if (workerStreet == null) {
                continue;
            }

            // 提取师傅证件信息，未同时不处理
            if (getCertificateInfo(workerCertificateInfo, worker.getWorkerId())){
                continue;
            }

            // 生成数据对象
            getreq(workerCertificateInfo, brand, sdf, req, worker, workerBrandAccount, workerStreet);

            // 日志
            log.info("报文：{}",JSONObject.toJSONString(req));

            // 同步
            syncData(workerBrandAccount, apiPathWork, item, req);

        }

        log.info("同步师傅信息到格力总部完成: {}",sdf.format(new Date()));
        return;
    }

    private Boolean getCertificateInfo(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证
        if (getsfz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 保险证
        if (getbxz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 高空作业证
        if (getgkz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 上岗资格证
        if (getsgz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 制冷工证
        if (getzlz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }
        // 驾驶证
        if (getjsz(workerCertificateInfo, workerId)){
            return Boolean.TRUE;
        }

        return Boolean.FALSE;
    }



    private Boolean getsfz(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证最近一次的同步情况
        // 看最大的id
        OutWorkerCertificateUpload maxidAll = outWorkerCertificateUploadService.getOne(
                Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                        .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                        .eq(OutWorkerCertificateUpload::getCertificateType, 1)
                        .orderByDesc(OutWorkerCertificateUpload::getId)
                        .last("limit 1"));
        // 身份证信息未同步，不操作
        if (!maxidAll.getSyncStatus().equals(1)){
            return Boolean.TRUE;
        } else {
            // 正反面都有信息且同步成功取值即可
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl()) && StringUtils.isNotEmpty(maxidAll.getFileUrl2())){
                workerCertificateInfo.setSfzz(maxidAll.getFileUrlOut());
                workerCertificateInfo.setSfzf(maxidAll.getFileUrl2Out());
                return Boolean.TRUE;
            }

            // 正面
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl())){
                workerCertificateInfo.setSfzz(maxidAll.getFileUrlOut());
                // 取最大的id 反面的同步信息
                OutWorkerCertificateUpload maxf = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 1)
                                .ne(OutWorkerCertificateUpload::getFileUrl2, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxf.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setSfzf(maxf.getFileUrl2Out());
            } else {
                workerCertificateInfo.setSfzf(maxidAll.getFileUrl2Out());
                // 取最大的id 正面的同步信息
                OutWorkerCertificateUpload maxz = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 1)
                                .ne(OutWorkerCertificateUpload::getFileUrl, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxz.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setSfzz(maxz.getFileUrlOut());
            }
        }

        return Boolean.FALSE;
    }

    private Boolean getgkz(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证最近一次的同步情况
        // 看最大的id
        OutWorkerCertificateUpload maxidAll = outWorkerCertificateUploadService.getOne(
                Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                        .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                        .eq(OutWorkerCertificateUpload::getCertificateType, 3)
                        .orderByDesc(OutWorkerCertificateUpload::getId)
                        .last("limit 1"));
        // 身份证信息未同步，不操作
        if (!maxidAll.getSyncStatus().equals(1)){
            return Boolean.TRUE;
        } else {
            // 正反面都有信息且同步成功取值即可
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl()) && StringUtils.isNotEmpty(maxidAll.getFileUrl2())){
                workerCertificateInfo.setGkzz(maxidAll.getFileUrlOut());
                workerCertificateInfo.setGkzf(maxidAll.getFileUrl2Out());
                return Boolean.TRUE;
            }

            // 正面
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl())){
                workerCertificateInfo.setGkzz(maxidAll.getFileUrlOut());
                // 取最大的id 反面的同步信息
                OutWorkerCertificateUpload maxf = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 3)
                                .ne(OutWorkerCertificateUpload::getFileUrl2, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxf.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setGkzf(maxf.getFileUrl2Out());
            } else {
                workerCertificateInfo.setGkzf(maxidAll.getFileUrl2Out());
                // 取最大的id 正面的同步信息
                OutWorkerCertificateUpload maxz = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 3)
                                .ne(OutWorkerCertificateUpload::getFileUrl, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxz.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setGkzz(maxz.getFileUrlOut());
            }
        }

        return Boolean.FALSE;
    }

    private Boolean getsgz(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证最近一次的同步情况
        // 看最大的id
        OutWorkerCertificateUpload maxidAll = outWorkerCertificateUploadService.getOne(
                Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                        .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                        .eq(OutWorkerCertificateUpload::getCertificateType, 4)
                        .orderByDesc(OutWorkerCertificateUpload::getId)
                        .last("limit 1"));
        // 身份证信息未同步，不操作
        if (!maxidAll.getSyncStatus().equals(1)){
            return Boolean.TRUE;
        } else {
            // 正反面都有信息且同步成功取值即可
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl()) && StringUtils.isNotEmpty(maxidAll.getFileUrl2())){
                workerCertificateInfo.setSgzgzz(maxidAll.getFileUrlOut());
                workerCertificateInfo.setSgzgzf(maxidAll.getFileUrl2Out());
                return Boolean.TRUE;
            }

            // 正面
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl())){
                workerCertificateInfo.setSgzgzz(maxidAll.getFileUrlOut());
                // 取最大的id 反面的同步信息
                OutWorkerCertificateUpload maxf = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 4)
                                .ne(OutWorkerCertificateUpload::getFileUrl2, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxf.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setSgzgzf(maxf.getFileUrl2Out());
            } else {
                workerCertificateInfo.setSgzgzf(maxidAll.getFileUrl2Out());
                // 取最大的id 正面的同步信息
                OutWorkerCertificateUpload maxz = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 4)
                                .ne(OutWorkerCertificateUpload::getFileUrl, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxz.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setSgzgzz(maxz.getFileUrlOut());
            }
        }

        return Boolean.FALSE;
    }

    private Boolean getzlz(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证最近一次的同步情况
        // 看最大的id
        OutWorkerCertificateUpload maxidAll = outWorkerCertificateUploadService.getOne(
                Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                        .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                        .eq(OutWorkerCertificateUpload::getCertificateType, 5)
                        .orderByDesc(OutWorkerCertificateUpload::getId)
                        .last("limit 1"));
        // 身份证信息未同步，不操作
        if (!maxidAll.getSyncStatus().equals(1)){
            return Boolean.TRUE;
        } else {
            // 正反面都有信息且同步成功取值即可
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl()) && StringUtils.isNotEmpty(maxidAll.getFileUrl2())){
                workerCertificateInfo.setZlgz(maxidAll.getFileUrlOut());
                workerCertificateInfo.setZlgf(maxidAll.getFileUrl2Out());
                return Boolean.TRUE;
            }

            // 正面
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl())){
                workerCertificateInfo.setZlgz(maxidAll.getFileUrlOut());
                // 取最大的id 反面的同步信息
                OutWorkerCertificateUpload maxf = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 5)
                                .ne(OutWorkerCertificateUpload::getFileUrl2, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxf.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setZlgf(maxf.getFileUrl2Out());
            } else {
                workerCertificateInfo.setZlgf(maxidAll.getFileUrl2Out());
                // 取最大的id 正面的同步信息
                OutWorkerCertificateUpload maxz = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 5)
                                .ne(OutWorkerCertificateUpload::getFileUrl, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxz.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setZlgz(maxz.getFileUrlOut());
            }
        }

        return Boolean.FALSE;
    }

    private Boolean getjsz(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证最近一次的同步情况
        // 看最大的id
        OutWorkerCertificateUpload maxidAll = outWorkerCertificateUploadService.getOne(
                Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                        .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                        .eq(OutWorkerCertificateUpload::getCertificateType, 6)
                        .orderByDesc(OutWorkerCertificateUpload::getId)
                        .last("limit 1"));
        // 身份证信息未同步，不操作
        if (!maxidAll.getSyncStatus().equals(1)){
            return Boolean.TRUE;
        } else {
            // 正反面都有信息且同步成功取值即可
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl()) && StringUtils.isNotEmpty(maxidAll.getFileUrl2())){
                workerCertificateInfo.setJszz(maxidAll.getFileUrlOut());
                workerCertificateInfo.setJszf(maxidAll.getFileUrl2Out());
                return Boolean.TRUE;
            }

            // 正面
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl())){
                workerCertificateInfo.setJszz(maxidAll.getFileUrlOut());
                // 取最大的id 反面的同步信息
                OutWorkerCertificateUpload maxf = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 6)
                                .ne(OutWorkerCertificateUpload::getFileUrl2, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxf.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setJszf(maxf.getFileUrl2Out());
            } else {
                workerCertificateInfo.setJszf(maxidAll.getFileUrl2Out());
                // 取最大的id 正面的同步信息
                OutWorkerCertificateUpload maxz = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 6)
                                .ne(OutWorkerCertificateUpload::getFileUrl, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxz.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setJszz(maxz.getFileUrlOut());
            }
        }

        return Boolean.FALSE;
    }

    private Boolean getbxz(WorkerCertificateInfo workerCertificateInfo, String workerId){
        // 身份证最近一次的同步情况
        // 看最大的id
        OutWorkerCertificateUpload maxidAll = outWorkerCertificateUploadService.getOne(
                Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                        .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                        .eq(OutWorkerCertificateUpload::getCertificateType, 2)
                        .orderByDesc(OutWorkerCertificateUpload::getId)
                        .last("limit 1"));
        // 身份证信息未同步，不操作
        if (!maxidAll.getSyncStatus().equals(1)){
            return Boolean.TRUE;
        } else {
            // 正反面都有信息且同步成功取值即可
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl()) && StringUtils.isNotEmpty(maxidAll.getFileUrl2())){
                workerCertificateInfo.setBxz(maxidAll.getFileUrlOut());
                workerCertificateInfo.setBxf(maxidAll.getFileUrl2Out());
                return Boolean.TRUE;
            }

            // 正面
            if (StringUtils.isNotEmpty(maxidAll.getFileUrl())){
                workerCertificateInfo.setBxz(maxidAll.getFileUrlOut());
                // 取最大的id 反面的同步信息
                OutWorkerCertificateUpload maxf = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 2)
                                .ne(OutWorkerCertificateUpload::getFileUrl2, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxf.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setBxf(maxf.getFileUrl2Out());
            } else {
                workerCertificateInfo.setBxf(maxidAll.getFileUrl2Out());
                // 取最大的id 正面的同步信息
                OutWorkerCertificateUpload maxz = outWorkerCertificateUploadService.getOne(
                        Wrappers.<OutWorkerCertificateUpload>lambdaQuery()
                                .eq(OutWorkerCertificateUpload::getWorkerId, workerId)
                                .eq(OutWorkerCertificateUpload::getCertificateType, 2)
                                .ne(OutWorkerCertificateUpload::getFileUrl, "")
                                .orderByDesc(OutWorkerCertificateUpload::getId)
                                .last("limit 1"));
                if (!maxz.getSyncStatus().equals(1)){
                    return Boolean.TRUE;
                }
                workerCertificateInfo.setBxz(maxz.getFileUrlOut());
            }
        }

        return Boolean.FALSE;
    }

    private void syncData(WorkerBrandAccount workerBrandAccount, String apiPath, WorkerUpload item, WorkUploadInfo req) throws Exception {
        GreeResponseHelper response = greeLogic.greePost(apiPath, JSONObject.toJSONString(req), 1);

        if (response.getStatus() == 200){
            // 成功 修改同步状态
            updateWorkerUploadSuccess(item);
            // 修改师傅品牌帐号
            updataWorker(workerBrandAccount.getId(), response);
        } else {
            // 失败 修改同步状态
            updateWorkerUploadError(item, response);
        }
    }

    private void updateWorkerUploadError(WorkerUpload item, GreeResponseHelper response) {
        WorkerUpload v = new WorkerUpload();
        v.setSynReqId(item.getSynReqId());
        v.setSynStatus(99);
        v.setSynTime(new Date());
        v.setSynTimes(item.getSynTimes()+1);

        if (response.getMsg().length()>255){
            v.setSynErrMsg(response.getMsg().substring(0,255));
        } else {
            v.setSynErrMsg(response.getMsg());
        }

        workerUploadService.updateById(v);
    }

    private void updataWorker(String id, GreeResponseHelper response) throws JsonProcessingException {
        WorkerBrandAccount w = new WorkerBrandAccount();
        w.setId(id);
        WorkerUploadResponse resultData = mapper.readValue(response.getData().toString(), WorkerUploadResponse.class);
        w.setBrandWorkerNumber(resultData.getWxgno());
        workerBrandAccountService.updateById(w);
    }

    private void updateWorkerUploadSuccess(WorkerUpload item) {
        WorkerUpload v = new WorkerUpload();
        v.setSynReqId(item.getSynReqId());
        v.setSynStatus(1);
        v.setSynTime(new Date());
        v.setSynTimes(item.getSynTimes()+1);
        v.setSynErrMsg("成功");
        workerUploadService.updateById(v);
    }

    private void getreq(WorkerCertificateInfo workerCertificateInfo, Brand brand, SimpleDateFormat sdf, WorkUploadInfo req, Worker worker,
                        WorkerBrandAccount workerBrandAccount, WorkerStreet workerStreet) throws Exception {
        List<SignSplb> jySignSplbList = new ArrayList<>();
        List<SignSplb> sySignSplbList = new ArrayList<>();
        List<ZJInfo> zjInfoList = new ArrayList<>();

        // 证件、品类信息
        setReqList(workerCertificateInfo, brand, zjInfoList, jySignSplbList, sySignSplbList, sdf, worker);

        // 生成数据对象
        setReq(zjInfoList, jySignSplbList, sySignSplbList, sdf, req, worker);

        // 不填值为新增，填值为修改
        if (StringUtils.isNotEmpty(workerBrandAccount.getBrandWorkerNumber())){
            req.setWxgno(workerBrandAccount.getBrandWorkerNumber());
        }

        // 所属网点
        req.setWdno(workerBrandAccount.getBrandWebsitNumber());

        // 省份-城市-区县-乡镇
        extractedPCAS(req, workerStreet);
    }

    private void extractedPCAS(WorkUploadInfo req, WorkerStreet workerStreet) {
        req.setSfen("");
        req.setCshi("");
        req.setCounty("");
        req.setXzhen("");
        if (StringUtils.isNotEmpty(workerStreet.getProvince())){
            req.setSfen(workerStreet.getProvince());
        }
        if (StringUtils.isNotEmpty(workerStreet.getCity())){
            req.setCshi(workerStreet.getCity());
        }
        if (StringUtils.isNotEmpty(workerStreet.getArea())){
            req.setCounty(workerStreet.getArea());
        }
        if (StringUtils.isNotEmpty(workerStreet.getStreet())){
            req.setXzhen(workerStreet.getStreet());
        }
    }

    private void setReq(List<ZJInfo> zjInfoList, List<SignSplb> jySignSplbList, List<SignSplb> sySignSplbList,
                        SimpleDateFormat sdf, WorkUploadInfo req, Worker worker) {
        req.setJySignSplbList(jySignSplbList);
        req.setSySignSplbList(sySignSplbList);
        req.setZjInfoList(zjInfoList);


        req.setWxgno("");// 不填值为新增，填值为修改
        req.setCsgzns(worker.getJobAge());
        // 必填
        req.setDizhi(worker.getAddress());
        req.setFacecheck(worker.getFaceCheck());
        req.setFacepath("");
        if (StringUtils.isNotEmpty(worker.getFacePath())){
            req.setFacepath(worker.getFacePath());
        }
        // 必填
        req.setFlag("有效");
        if (worker.getStatus().equals("OFF")){
            req.setFlag("无效");
        }
        // 必填
        req.setFwryzpfj("www");
        if (StringUtils.isNotEmpty(worker.getImgUrl())){
            req.setFwryzpfj(worker.getImgUrl());
        }
        req.setGzkkh("");
        if (StringUtils.isNotEmpty(worker.getBankAccount())){
            req.setGzkkh(worker.getBankAccount());
        }
        req.setGzkssyh("");
        if (StringUtils.isNotEmpty(worker.getBankDeposit())){
            req.setGzkssyh(worker.getBankDeposit());
        }
        req.setHasfaceFlag(Boolean.FALSE);
        if (worker.getHasFace()==1){
            req.setHasfaceFlag(Boolean.TRUE);
        }
        req.setHmdbz("");
        if (StringUtils.isNotEmpty(worker.getBlackListRemark())){
            req.setHmdbz(worker.getBlackListRemark());
        }
        // 必填
        req.setIfmessageFlag(Boolean.FALSE);
        if (worker.getIsSmsNotice().equals("YES")){
            req.setIfmessageFlag(Boolean.TRUE);
        }
        req.setNianl(worker.getAge());
        req.setPxhgkssj("");
        if (worker.getTrainPassTime() !=null ){
            req.setPxhgkssj(sdf.format(worker.getTrainPassTime()));
        }
        req.setQbaoid("");
        req.setQbcheackFlag(Boolean.FALSE);
        req.setSfdswxgFlag(Boolean.FALSE);

        // 必填
        req.setSfhmdFlag(Boolean.FALSE);
        if (worker.getIsBlackList().equals("YES")){
            req.setSfhmdFlag(Boolean.TRUE);
        }
        req.setSfpxhgFlag(Boolean.FALSE);
        if (worker.getTrainStatus()){
            req.setSfpxhgFlag(Boolean.TRUE);
        }
        // 必填
        req.setSfzstFlag(Boolean.FALSE);
        if (worker.getIsZst().equals("YES")){
            req.setSfzstFlag(Boolean.TRUE);
        }
        req.setVipflag(worker.getVipFlag());

        req.setWxfensu(worker.getScore());
        // 必填
        req.setWxgmc(worker.getWorkerName());
        req.setXcsgz("");
        if (StringUtils.isNotEmpty(worker.getJob())){
            req.setXcsgz(worker.getJob());
        }
        // 必填
        req.setXingb(worker.getGender());

        // 必填 必须初中以下
        req.setXueli("中专");
        if (StringUtils.isNotEmpty(worker.getEducation())){
            req.setXueli(worker.getEducation());
        }
        // 必填
        req.setYddh("123");
        if (StringUtils.isNotEmpty(worker.getMobile())){
            req.setYddh(worker.getMobile());
        }
        req.setYxcjgcjgdl(worker.getCollectEnginLimitNum());
        req.setYxcjgdl(worker.getCollectLimitNum());
    }

    private void setReqList(WorkerCertificateInfo workerCertificateInfo, Brand brand, List<ZJInfo> zjInfoList, List<SignSplb> jySignSplbList,
                            List<SignSplb> sySignSplbList, SimpleDateFormat sdf, Worker worker) throws Exception {

        // 证件信息
        getcert(workerCertificateInfo, zjInfoList, sdf, worker);

        // 签约品类
        getCategory(brand, jySignSplbList, sySignSplbList, worker);
    }

    private void getCategory(Brand brand, List<SignSplb> jySignSplbList, List<SignSplb> sySignSplbList, Worker worker) {
        List<String> SYDictCode = new ArrayList<>();

        // 师傅服务的大类： worker_service_category_detail
        // 对应关系表  sys_dict_ref
        // 提取所有的商用大类信息
        List<SysDict> sysDicts = sysDictService.lambdaQuery()
                .eq(SysDict::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                .eq(SysDict::getFlag, DictTypeEnum.DICT_TYPE_FLAG_SY.getCode()).list();
        if (sysDicts !=null && sysDicts.size()>0){
            SYDictCode = sysDicts.stream().map(SysDict::getDictCode).collect(Collectors.toList());
        }

        // 提取师傅的服务大类信息
        List<WorkerServiceCategoryDetail> categoryRecs = workerServiceCategoryDetailService.lambdaQuery()
                .eq(WorkerServiceCategoryDetail::getWorkerId, worker.getWorkerId()).list();
        if (categoryRecs !=null && categoryRecs.size()>0){
            List<String> caregoryIds = categoryRecs.stream().map(WorkerServiceCategoryDetail::getMainId).collect(Collectors.toList());

            // 提取对应的大类信息
            List<SysDictRef> sysDictRefs =  sysDictRefService.lambdaQuery()
                    .eq(SysDictRef::getBrandId, brand.getBrandId())
                    .eq(SysDictRef::getDictType, DictTypeEnum.DICT_TYPE_MAIN_TYPE.getCode())
                    .in(SysDictRef::getDictCode,caregoryIds).list();
            if (sysDictRefs !=null && sysDictRefs.size()>0){
                for (SysDictRef item:sysDictRefs){
                    SignSplb v = new SignSplb();
                    v.setSpdl(Integer.valueOf(item.getRefDictCode()));
                    v.setSpdlName(item.getRefDictName());
                    // v.setSpxl(0);
                    // v.setSpxlName("");
                    v.getFwlbList().add(item.getRefDictName());
                    // 查看是否为商用
                    if (SYDictCode.contains(item.getDictCode())){
                        sySignSplbList.add(v);
                    } else {
                        jySignSplbList.add(v);
                    }
                }

            }
        }
    }

    private void getcert(WorkerCertificateInfo workerCertificateInfo, List<ZJInfo> zjInfoList, SimpleDateFormat sdf, Worker worker) throws Exception {
        // 身份证  OK
        if (StringUtils.isNotEmpty(worker.getIdcard())) {
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(worker.getIdcard());
            zjInfo.setZjfssj("");
            if (worker.getCertExamineTime() != null) {
                zjInfo.setZjfssj(sdf.format(worker.getCertExamineTime()));
            }
            // 必填
            zjInfo.setZjlj("www");
            zjInfo.setZjmc("1");
            zjInfo.setZjyxq("");

            // 证件路径
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzz())) {
                zjInfo.setZjlj(workerCertificateInfo.getSfzz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getSfzz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getSfzf());
                }
                zjInfo.setZjlj(workerCertificateInfo.getSfzz());
            }

            //提取身份证有效期
            WorkerCert workerCert = workerCertService.lambdaQuery()
                    .eq(WorkerCert::getWorkerId, worker.getWorkerId())
                    .eq(WorkerCert::getCertNo, worker.getIdcard()).one();
            if (workerCert != null) {
                zjInfo.setZjyxq(sdf.format(workerCert.getExpireTime()));
                if (workerCert.getReviewTime() != null) {
                    zjInfo.setZjfssj(sdf.format(workerCert.getReviewTime()));
                }
                zjInfoList.add(zjInfo);
            }
        }

        // 保险  家用保险差图片
        if (StringUtils.isNotEmpty(worker.getSafeNo())){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(worker.getSafeCompany()+"/"+ worker.getSafeNo());
            zjInfo.setZjfssj("");
            if (worker.getCertExamineTime() !=null){
                zjInfo.setZjfssj(sdf.format(worker.getCertExamineTime()));
            }
            // 必填
            zjInfo.setZjlj("www");
            zjInfo.setZjmc("2");
            zjInfo.setZjyxq("");
            if (worker.getGmbxyxq() !=null){
                zjInfo.setZjyxq(sdf.format(worker.getGmbxyxq()));
            }

            // 证件路径
            if (StringUtils.isNotEmpty(workerCertificateInfo.getBxz())) {
                zjInfo.setZjlj(workerCertificateInfo.getBxz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getBxf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getBxz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getBxf());
                }
                zjInfo.setZjlj(workerCertificateInfo.getBxz());
            }

            zjInfoList.add(zjInfo);
        }



        // 高空作业证
        WorkerCert workerCert = workerCertService.lambdaQuery()
                .eq(WorkerCert::getWorkerId, worker.getWorkerId())
                .like(WorkerCert::getCertName,"高空").one();
        if (workerCert != null){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCert.getCertNo());
            zjInfo.setZjfssj("高空作业证必填");
            if (workerCert.getReviewTime() !=null ){
                zjInfo.setZjfssj(sdf.format(workerCert.getReviewTime()));
            }
            // 必填
            zjInfo.setZjlj("www");
            // 证件路径
            if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzz())) {
                zjInfo.setZjlj(workerCertificateInfo.getGkzz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getGkzz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getGkzf());
                }
                zjInfo.setZjlj(workerCertificateInfo.getGkzz());
            }

            zjInfo.setZjmc("3");
            zjInfo.setZjyxq(sdf.format(workerCert.getExpireTime()));
            zjInfoList.add(zjInfo);
        }


        // 上岗资格证
        WorkerCert workerCertT = workerCertService.lambdaQuery()
                .eq(WorkerCert::getWorkerId, worker.getWorkerId())
                .like(WorkerCert::getCertName,"上岗").one();
        if (workerCertT != null){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertT.getCertNo());
            zjInfo.setZjfssj("制冷工证必填");
            if (workerCertT.getReviewTime() !=null ){
                zjInfo.setZjfssj(sdf.format(workerCertT.getReviewTime()));
            }

            // 必填
            zjInfo.setZjlj("www");
            // 证件路径
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzz())) {
                zjInfo.setZjlj(workerCertificateInfo.getSgzgzz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getSgzgzz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getSgzgzf());
                }
                zjInfo.setZjlj(workerCertificateInfo.getSgzgzz());
            }

            zjInfo.setZjmc("4");
            zjInfo.setZjyxq(sdf.format(workerCertT.getExpireTime()));
            zjInfoList.add(zjInfo);
        }

        // 制冷工证
        WorkerCert workerCertTR = workerCertService.lambdaQuery()
                .eq(WorkerCert::getWorkerId, worker.getWorkerId())
                .like(WorkerCert::getCertName,"制冷").one();
        if (workerCertTR != null){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(workerCertTR.getCertNo());
            zjInfo.setZjfssj("");
            if (workerCertTR.getReviewTime() !=null ){
                zjInfo.setZjfssj(sdf.format(workerCertTR.getReviewTime()));
            }
            // 必填
            zjInfo.setZjlj("www");
            // 证件路径
            if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgz())) {
                zjInfo.setZjlj(workerCertificateInfo.getZlgz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getZlgz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getZlgf());
                }
                zjInfo.setZjlj(workerCertificateInfo.getZlgz());
            }

            zjInfo.setZjmc("5");
            zjInfo.setZjyxq(sdf.format(workerCertTR.getExpireTime()));
            zjInfoList.add(zjInfo);
        }

        // 驾驶证
        if (StringUtils.isNotEmpty(worker.getCarNo())){
            ZJInfo zjInfo = new ZJInfo();
            zjInfo.setZjbh(worker.getCarNo());
            if (StringUtils.isNotEmpty(worker.getGpsMachineId())){
                zjInfo.setZjbh(worker.getCarNo()+"/"+ worker.getGpsMachineId());
            }
            zjInfo.setZjfssj("");
            if (worker.getCertExamineTime() !=null){
                zjInfo.setZjfssj(sdf.format(worker.getCertExamineTime()));
            }
            // 必填
            zjInfo.setZjlj("www");
            zjInfo.setZjmc("6");
            zjInfo.setZjyxq("");

            // 证件路径
            if (StringUtils.isNotEmpty(workerCertificateInfo.getJszz())) {
                zjInfo.setZjlj(workerCertificateInfo.getJszz());
            }
            if (StringUtils.isNotEmpty(workerCertificateInfo.getJszf())) {
                if (StringUtils.isNotEmpty(workerCertificateInfo.getJszz())) {
                    zjInfo.setZjlj(zjInfo.getZjlj() + "," + workerCertificateInfo.getJszf());
                }
                zjInfo.setZjlj(workerCertificateInfo.getJszz());
            }

            //提取驾驶证
            WorkerCert workerCertj = workerCertService.lambdaQuery()
                    .eq(WorkerCert::getWorkerId, worker.getWorkerId())
                    .eq(WorkerCert::getCertNo, worker.getCarNo()).one();
            if (workerCertj != null){
                zjInfo.setZjyxq(sdf.format(workerCertj.getExpireTime()));
                if (workerCertj.getReviewTime() !=null ){
                    zjInfo.setZjfssj(sdf.format(workerCertj.getReviewTime()));
                }
                if (workerCertj.getFileUrl() !=null ){
                    zjInfo.setZjlj(workerCertj.getFileUrl());
                }
                if (workerCertj.getFileUrl2() !=null ){
                    if (workerCertj.getFileUrl() !=null ){
                        zjInfo.setZjlj(zjInfo.getZjlj()+","+workerCertj.getFileUrl2());
                    } else {
                        zjInfo.setZjlj(workerCertj.getFileUrl2());
                    }
                }
            }

            zjInfoList.add(zjInfo);
        }
    }

    @Nullable
    private WorkerStreet getWorkerStreet(WorkerUpload item, Worker worker) {
        WorkerStreet workerStreet = workerStreetService.lambdaQuery()
                .eq(WorkerStreet::getWorkerId, worker.getWorkerId()).one();
        if (workerStreet == null){
            // 写入表备注信息
            updateWorkerUploadLag(item,"师傅服务区域信息不存在");
            return null;
        }
        return workerStreet;
    }

    private void updateWorkerUploadLag(WorkerUpload item, String msg) {
        WorkerUpload v = new WorkerUpload();
        v.setSynReqId(item.getSynReqId());
        v.setSynTime(new Date());
        v.setSynErrMsg(msg);
        workerUploadService.updateById(v);
    }

    @Nullable
    private WorkerBrandAccount getWorkerBrandAccount(Brand brand, WorkerUpload item, Worker worker) {
        WorkerBrandAccount workerBrandAccount = workerBrandAccountService.lambdaQuery()
                .eq(WorkerBrandAccount::getWorkerId, worker.getWorkerId())
                .eq(WorkerBrandAccount::getBrandId, brand.getBrandId()).one();

        if (workerBrandAccount == null){
            // 写入表备注信息
            updateWorkerUploadLag(item,"师傅未选择品牌商");
            return null;
        }
        return workerBrandAccount;
    }

    @Nullable
    private Worker getWorker(WorkerUpload item) {
        Worker worker = workerService.lambdaQuery()
                .eq(Worker::getWorkerId, item.getWorkerId())
                .eq(Worker::getIsApplyOver,"YES").one();
        if (worker ==null){
            return null;
        }
        return worker;
    }

    private List<WorkerUpload> getWorkerUploads() {
        // 同步标志-synStatus(0:待同步;1:已同步;99:同步失败)
        List<WorkerUpload> recs;
        LambdaQueryWrapper<WorkerUpload> queryWrapper = new LambdaQueryWrapper<WorkerUpload>()
                .eq(WorkerUpload::getSynStatus,0)
                .or(wrapper->wrapper.eq(WorkerUpload::getSynStatus,99)
                        .le(WorkerUpload::getSynTimes,10));
        recs = workerUploadService.list(queryWrapper);
        return recs;
    }
}
